@@ -64,46 +64,118 @@ impl Backend for AquaBackend {
 
         let mut features = vec![];
 
-        // Checksum
-        if let Some(checksum) = &pkg.checksum
-            && checksum.enabled()
-        {
-            features.push(SecurityFeature::Checksum {
-                algorithm: checksum.algorithm.as_ref().map(|a| a.to_string()),
-            });
+        // Check base package and all version overrides for security features
+        // This gives a complete picture of available security features across all versions
+        let all_pkgs: Vec<&AquaPackage> = std::iter::once(&pkg)
+            .chain(pkg.version_overrides.iter())
+            .collect();
+
+        // Fetch release assets to detect actual security features
+        let release_assets = if !pkg.repo_owner.is_empty() && !pkg.repo_name.is_empty() {
+            let repo = format!("{}/{}", pkg.repo_owner, pkg.repo_name);
+            github::list_releases(&repo)
+                .await
+                .ok()
+                .and_then(|releases| releases.first().cloned())
+                .map(|r| r.assets)
+                .unwrap_or_default()
+        } else {
+            vec![]
+        };
+
+        // Checksum - check registry config OR actual release assets
+        let has_checksum_config = all_pkgs.iter().any(|p| {
+            p.checksum
+                .as_ref()
+                .is_some_and(|checksum| checksum.enabled())
+        });
+        let has_checksum_assets = release_assets.iter().any(|a| {
+            let name = a.name.to_lowercase();
+            name.contains("sha256")
+                || name.contains("checksum")
+                || name.ends_with(".sha256")
+                || name.ends_with(".sha512")
+        });
+        if has_checksum_config || has_checksum_assets {
+            let algorithm = all_pkgs
+                .iter()
+                .filter_map(|p| p.checksum.as_ref())
+                .find_map(|c| c.algorithm.as_ref().map(|a| a.to_string()))
+                .or_else(|| {
+                    if has_checksum_assets {
+                        Some("sha256".to_string())
+                    } else {
+                        None
+                    }
+                });
+            features.push(SecurityFeature::Checksum { algorithm });
         }
 
-        // GitHub Attestations
-        if let Some(attestations) = &pkg.github_artifact_attestations
-            && attestations.enabled.unwrap_or(false)
-        {
-            features.push(SecurityFeature::GithubAttestations {
-                signer_workflow: attestations.signer_workflow.clone(),
-            });
+        // GitHub Attestations - check registry config OR actual release assets
+        let has_attestations_config = all_pkgs.iter().any(|p| {
+            p.github_artifact_attestations
+                .as_ref()
+                .is_some_and(|a| a.enabled.unwrap_or(true))
+        });
+        let has_attestations_assets = release_assets.iter().any(|a| {
+            let name = a.name.to_lowercase();
+            name.ends_with(".sigstore.json") || name.ends_with(".sigstore")
+        });
+        if has_attestations_config || has_attestations_assets {
+            let signer_workflow = all_pkgs
+                .iter()
+                .filter_map(|p| p.github_artifact_attestations.as_ref())
+                .find_map(|a| a.signer_workflow.clone());
+            features.push(SecurityFeature::GithubAttestations { signer_workflow });
         }
 
-        // SLSA
-        if let Some(slsa) = &pkg.slsa_provenance
-            && slsa.enabled.unwrap_or(false)
-        {
-            features.push(SecurityFeature::Slsa);
+        // SLSA - check registry config OR actual release assets
+        let has_slsa_config = all_pkgs.iter().any(|p| {
+            p.slsa_provenance
+                .as_ref()
+                .is_some_and(|s| s.enabled.unwrap_or(true))
+        });
+        let has_slsa_assets = release_assets.iter().any(|a| {
+            let name = a.name.to_lowercase();
+            name.contains(".intoto.jsonl")
+                || name.contains("provenance")
+                || name.ends_with(".attestation")
+        });
+        if has_slsa_config || has_slsa_assets {
+            features.push(SecurityFeature::Slsa { level: None });
         }
 
-        // Cosign (nested in checksum)
-        if let Some(checksum) = &pkg.checksum
-            && let Some(cosign) = &checksum.cosign
-            && cosign.enabled.unwrap_or(false)
-        {
+        // Cosign (nested in checksum) - check registry config OR actual release assets
+        let has_cosign_config = all_pkgs.iter().any(|p| {
+            p.checksum
+                .as_ref()
+                .and_then(|c| c.cosign.as_ref())
+                .is_some_and(|cosign| cosign.enabled.unwrap_or(true))
+        });
+        let has_cosign_assets = release_assets.iter().any(|a| {
+            let name = a.name.to_lowercase();
+            name.ends_with(".sig") || name.contains("cosign")
+        });
+        if has_cosign_config || has_cosign_assets {
             features.push(SecurityFeature::Cosign);
         }
 
-        // Minisign
-        if let Some(minisign) = &pkg.minisign
-            && minisign.enabled.unwrap_or(false)
-        {
-            features.push(SecurityFeature::Minisign {
-                public_key: minisign.public_key.clone(),
-            });
+        // Minisign - check registry config OR actual release assets
+        let has_minisign_config = all_pkgs.iter().any(|p| {
+            p.minisign
+                .as_ref()
+                .is_some_and(|m| m.enabled.unwrap_or(true))
+        });
+        let has_minisign_assets = release_assets.iter().any(|a| {
+            let name = a.name.to_lowercase();
+            name.ends_with(".minisig")
+        });
+        if has_minisign_config || has_minisign_assets {
+            let public_key = all_pkgs
+                .iter()
+                .filter_map(|p| p.minisign.as_ref())
+                .find_map(|m| m.public_key.clone());
+            features.push(SecurityFeature::Minisign { public_key });
         }
 
         features
@@ -113,10 +185,7 @@ impl Backend for AquaBackend {
         &self.ba
     }
 
-    async fn _list_remote_versions_with_info(
-        &self,
-        _config: &Arc<Config>,
-    ) -> Result<Vec<VersionInfo>> {
+    async fn _list_remote_versions(&self, _config: &Arc<Config>) -> Result<Vec<VersionInfo>> {
         let pkg = match AQUA_REGISTRY.package(&self.id).await {
             Ok(pkg) => pkg,
             Err(e) => {
@@ -290,6 +359,11 @@ impl Backend for AquaBackend {
                 (url, v.to_string(), filename, digest)
             };
 
+        // Determine operation count for progress reporting
+        let format = pkg.format(&v, os(), arch()).unwrap_or_default();
+        let op_count = Self::calculate_op_count(&pkg, &api_digest, format);
+        ctx.pr.start_operations(op_count);
+
         self.download(ctx, &tv, &url, &filename).await?;
 
         if existing_platform.is_none() {
@@ -557,6 +631,29 @@ impl AquaBackend {
         }
     }
 
+    /// Calculate the number of operations for progress reporting.
+    /// Operations: download (always), checksum (if enabled or api_digest), extraction (if needed)
+    fn calculate_op_count(pkg: &AquaPackage, api_digest: &Option<String>, format: &str) -> usize {
+        let mut op_count = 1; // download
+
+        // Checksum verification (from pkg config or GitHub API digest)
+        if pkg.checksum.as_ref().is_some_and(|c| c.enabled()) || api_digest.is_some() {
+            op_count += 1;
+        }
+
+        // Extraction (for archives, or GithubArchive/GithubContent which always extract)
+        if (!format.is_empty() && format != "raw")
+            || matches!(
+                pkg.r#type,
+                AquaPackageType::GithubArchive | AquaPackageType::GithubContent
+            )
+        {
+            op_count += 1;
+        }
+
+        op_count
+    }
+
     async fn github_release_url(
         &self,
         pkg: &AquaPackage,
@@ -809,7 +906,7 @@ impl AquaBackend {
         v: &str,
         filename: &str,
     ) -> Result<()> {
-        if !Settings::get().aqua.slsa {
+        if !Settings::get().aqua.minisign {
             return Ok(());
         }
         if let Some(minisign) = &pkg.minisign {
@@ -866,7 +963,8 @@ impl AquaBackend {
         v: &str,
         filename: &str,
     ) -> Result<()> {
-        if !Settings::get().aqua.slsa {
+        let settings = Settings::get();
+        if !settings.slsa || !settings.aqua.slsa {
             return Ok(());
         }
         if let Some(slsa) = &pkg.slsa_provenance {
@@ -968,8 +1066,9 @@ impl AquaBackend {
         _v: &str,
         filename: &str,
     ) -> Result<()> {
-        // Check if attestations are enabled via settings
-        if !Settings::get().aqua.github_attestations {
+        // Check if attestations are enabled via global and aqua-specific settings
+        let settings = Settings::get();
+        if !settings.github_attestations || !settings.aqua.github_attestations {
             debug!("GitHub attestations verification disabled");
             return Ok(());
         }
