@@ -779,6 +779,12 @@ pub trait Backend: Debug + Send + Sync {
 
         ctx.pr.set_message("install".into());
         let _lock = lock_file::get(&tv.install_path(), ctx.force)?;
+
+        // Double-checked (locking) that it wasn't installed while we were waiting for the lock
+        if self.is_version_installed(&ctx.config, &tv, true) && !ctx.force {
+            return Ok(tv);
+        }
+
         self.create_install_dirs(&tv)?;
 
         let old_tv = tv.clone();
@@ -845,8 +851,6 @@ pub trait Backend: Debug + Send + Sync {
         CmdLineRunner::new(&*env::SHELL)
             .env(&*env::PATH_KEY, plugins::core::path_env_with_tv_path(tv)?)
             .env("MISE_TOOL_INSTALL_PATH", tv.install_path())
-            .env("MISE_TOOL_NAME", &tv.ba().short)
-            .env("MISE_TOOL_VERSION", &tv.version)
             .with_pr(ctx.pr.as_ref())
             .arg(env::SHELL_COMMAND_FLAG)
             .arg(script)
