@@ -55,6 +55,7 @@ pub struct Config {
     pub vars: IndexMap<String, String>,
     pub tera_ctx: tera::Context,
     pub shorthands: Shorthands,
+    pub shell_aliases: EnvWithSources,
     aliases: AliasMap,
     env: OnceCell<EnvResults>,
     env_with_sources: OnceCell<EnvWithSources>,
@@ -141,6 +142,7 @@ impl Config {
             aliases: Default::default(),
             project_root: Default::default(),
             repo_urls: Default::default(),
+            shell_aliases: Default::default(),
             vars: Default::default(),
             vars_loader: None,
             vars_results: OnceCell::new(),
@@ -159,6 +161,7 @@ impl Config {
             aliases: config.aliases.clone(),
             project_root: config.project_root.clone(),
             repo_urls: config.repo_urls.clone(),
+            shell_aliases: config.shell_aliases.clone(),
             vars: config.vars.clone(),
             vars_loader: None,
             vars_results: OnceCell::new(),
@@ -179,6 +182,7 @@ impl Config {
 
         config.vars = vars;
         config.aliases = load_aliases(&config.config_files)?;
+        config.shell_aliases = load_shell_aliases(&config.config_files)?;
         config.project_root = get_project_root(&config.config_files);
         config.repo_urls = load_plugins(&config.config_files)?;
         measure!("config::load validate", {
@@ -983,6 +987,9 @@ pub fn load_config_paths(config_filenames: &[String], include_ignored: bool) ->
         .into_iter()
         .unique_by(|p| file::desymlink_path(p))
         .filter(|p| {
+            if is_default_config_dir_override_filtered(p) {
+                return false;
+            }
             include_ignored
                 || !(config_file::is_ignored(&config_trust_root(p)) || config_file::is_ignored(p))
         })
@@ -1027,7 +1034,12 @@ pub fn load_config_hierarchy_from_dir(start_dir: &Path) -> Result<Vec<PathBuf>>
     let paths = config_files
         .into_iter()
         .unique_by(|p| file::desymlink_path(p))
-        .filter(|p| !(config_file::is_ignored(&config_trust_root(p)) || config_file::is_ignored(p)))
+        .filter(|p| {
+            if is_default_config_dir_override_filtered(p) {
+                return false;
+            }
+            !(config_file::is_ignored(&config_trust_root(p)) || config_file::is_ignored(p))
+        })
         .collect();
 
     Ok(paths)
@@ -1037,6 +1049,16 @@ pub fn is_global_config(path: &Path) -> bool {
     global_config_files().contains(path) || system_config_files().contains(path)
 }
 
+/// Returns true if the path should be filtered out due to MISE_CONFIG_DIR override.
+/// When MISE_CONFIG_DIR is set to a non-default location, this filters out configs
+/// found under the default location (~/.config/mise) during traversal.
+/// See: https://github.com/jdx/mise/discussions/7015
+fn is_default_config_dir_override_filtered(path: &Path) -> bool {
+    *env::MISE_CONFIG_DIR_OVERRIDDEN
+        && !global_config_files().contains(path)
+        && path.starts_with(&*env::MISE_DEFAULT_CONFIG_DIR)
+}
+
 static GLOBAL_CONFIG_FILES: Lazy<Mutex<Option<IndexSet<PathBuf>>>> = Lazy::new(Default::default);
 static SYSTEM_CONFIG_FILES: Lazy<Mutex<Option<IndexSet<PathBuf>>>> = Lazy::new(Default::default);
 
@@ -1313,6 +1335,21 @@ fn load_aliases(config_files: &ConfigMap) -> Result<AliasMap> {
     Ok(aliases)
 }
 
+fn load_shell_aliases(config_files: &ConfigMap) -> Result<EnvWithSources> {
+    let mut shell_aliases: EnvWithSources = EnvWithSources::new();
+
+    // Iterate in reverse order (global -> local) so child directories override parent configs
+    for config_file in config_files.values().rev() {
+        let path = config_file.get_path().to_path_buf();
+        for (name, cmd) in config_file.shell_aliases()? {
+            shell_aliases.insert(name, (cmd, path.clone()));
+        }
+    }
+    trace!("load_shell_aliases: {}", shell_aliases.len());
+
+    Ok(shell_aliases)
+}
+
 fn load_plugins(config_files: &ConfigMap) -> Result<HashMap<String, String>> {
     let mut plugins = HashMap::new();
     for config_file in config_files.values() {
