@@ -92,21 +92,17 @@ pub static MISE_TOOL_STUB: Lazy<bool> =
     Lazy::new(|| ARGS.read().unwrap().get(1).map(|s| s.as_str()) == Some("tool-stub"));
 pub static MISE_NO_CONFIG: Lazy<bool> = Lazy::new(|| var_is_true("MISE_NO_CONFIG"));
 pub static MISE_PROGRESS_TRACE: Lazy<bool> = Lazy::new(|| var_is_true("MISE_PROGRESS_TRACE"));
-/// true if RUST_BACKTRACE is set (enables detailed error tracebacks)
-pub static RUST_BACKTRACE: Lazy<bool> = Lazy::new(|| {
-    match var("RUST_BACKTRACE") {
-        Ok(v) => {
-            let v = v.to_lowercase();
-            // RUST_BACKTRACE accepts "1" and "full" as valid values
-            v == "1" || v == "full"
-        }
-        Err(_) => false,
-    }
-});
 pub static MISE_CACHE_DIR: Lazy<PathBuf> =
     Lazy::new(|| var_path("MISE_CACHE_DIR").unwrap_or_else(|| XDG_CACHE_HOME.join("mise")));
 pub static MISE_CONFIG_DIR: Lazy<PathBuf> =
     Lazy::new(|| var_path("MISE_CONFIG_DIR").unwrap_or_else(|| XDG_CONFIG_HOME.join("mise")));
+/// The default config directory location (XDG_CONFIG_HOME/mise), used to filter out
+/// configs from this location when MISE_CONFIG_DIR is set to a different path
+pub static MISE_DEFAULT_CONFIG_DIR: Lazy<PathBuf> = Lazy::new(|| XDG_CONFIG_HOME.join("mise"));
+/// True if MISE_CONFIG_DIR was explicitly set to a non-default location
+pub static MISE_CONFIG_DIR_OVERRIDDEN: Lazy<bool> = Lazy::new(|| {
+    var_path("MISE_CONFIG_DIR").is_some() && *MISE_CONFIG_DIR != *MISE_DEFAULT_CONFIG_DIR
+});
 pub static MISE_DATA_DIR: Lazy<PathBuf> =
     Lazy::new(|| var_path("MISE_DATA_DIR").unwrap_or_else(|| XDG_DATA_HOME.join("mise")));
 pub static MISE_STATE_DIR: Lazy<PathBuf> =
@@ -223,6 +219,7 @@ pub static MISE_SELF_UPDATE_INSTRUCTIONS: Lazy<Option<PathBuf>> = Lazy::new(|| {
         ],
     )
 });
+#[cfg(feature = "self_update")]
 pub static MISE_SELF_UPDATE_AVAILABLE: Lazy<Option<bool>> = Lazy::new(|| {
     if var_is_true("MISE_SELF_UPDATE_AVAILABLE") {
         Some(true)
@@ -232,6 +229,7 @@ pub static MISE_SELF_UPDATE_AVAILABLE: Lazy<Option<bool>> = Lazy::new(|| {
         None
     }
 });
+#[cfg(feature = "self_update")]
 pub static MISE_SELF_UPDATE_DISABLED_PATH: Lazy<Option<PathBuf>> = Lazy::new(|| {
     let base = mise_install_base()?;
     find_in_tree(
