@@ -61,11 +61,13 @@ pub(crate) mod logger;
 pub(crate) mod maplit;
 mod migrate;
 mod minisign;
+mod netrc;
 pub(crate) mod parallel;
 mod path;
 mod path_env;
 mod platform;
 mod plugins;
+mod prepare;
 mod rand;
 mod redactions;
 mod registry;
