@@ -89,10 +89,7 @@ impl Backend for ElixirPlugin {
         &self.ba
     }
 
-    async fn _list_remote_versions_with_info(
-        &self,
-        _config: &Arc<Config>,
-    ) -> Result<Vec<VersionInfo>> {
+    async fn _list_remote_versions(&self, _config: &Arc<Config>) -> Result<Vec<VersionInfo>> {
         // Format: "version hash timestamp checksum"
         // Example: "v1.17.3 abc123 2024-12-01T00:00:00Z def456"
         let versions: Vec<VersionInfo> = HTTP_FETCH
@@ -142,6 +139,7 @@ impl Backend for ElixirPlugin {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> Result<ToolVersion> {
+        ctx.pr.start_operations(3);
         let tarball_path = self.download(&tv, ctx.pr.as_ref()).await?;
         self.verify_checksum(ctx, &mut tv, &tarball_path)?;
         self.install(ctx, &tv, &tarball_path).await?;
