@@ -14,6 +14,14 @@ use std::sync::{Arc, Mutex};
 use tokio::task::JoinSet;
 use versions::Versioning;
 
+/// Normalize a version string for sorting by stripping leading 'v' or 'V' prefix.
+/// This ensures "v1.0.0" and "1.0.0" are sorted together correctly.
+fn normalize_version_for_sort(v: &str) -> &str {
+    v.strip_prefix('v')
+        .or_else(|| v.strip_prefix('V'))
+        .unwrap_or(v)
+}
+
 type InstallStatePlugins = BTreeMap<String, PluginType>;
 type InstallStateTools = BTreeMap<String, InstallStateTool>;
 type MutexResult<T> = Result<Arc<T>>;
@@ -100,7 +108,12 @@ async fn init_tools() -> MutexResult<InstallStateTools> {
                 .filter(|v| !v.starts_with('.'))
                 .filter(|v| !runtime_symlinks::is_runtime_symlink(&dir.join(v)))
                 .filter(|v| !dir.join(v).join("incomplete").exists())
-                .sorted_by_cached_key(|v| (Versioning::new(v), v.to_string()))
+                .sorted_by_cached_key(|v| {
+                    // Normalize version for sorting to handle mixed v-prefix versions
+                    // e.g., "v2.0.51" and "2.0.35" should sort by numeric value
+                    let normalized = normalize_version_for_sort(v);
+                    (Versioning::new(normalized), v.to_string())
+                })
                 .collect();
             let tool = InstallStateTool {
                 short: short.clone(),
@@ -288,3 +301,51 @@ pub fn reset() {
         .lock()
         .expect("INSTALL_STATE_TOOLS lock failed") = None;
 }
+
+#[cfg(test)]
+mod tests {
+    use super::normalize_version_for_sort;
+    use itertools::Itertools;
+    use versions::Versioning;
+
+    #[test]
+    fn test_normalize_version_for_sort() {
+        assert_eq!(normalize_version_for_sort("v1.0.0"), "1.0.0");
+        assert_eq!(normalize_version_for_sort("V1.0.0"), "1.0.0");
+        assert_eq!(normalize_version_for_sort("1.0.0"), "1.0.0");
+        assert_eq!(normalize_version_for_sort("latest"), "latest");
+    }
+
+    #[test]
+    fn test_version_sorting_with_v_prefix() {
+        // Test that mixed v-prefix and non-v-prefix versions sort correctly
+        let versions = ["v2.0.51", "2.0.35", "2.0.52"];
+
+        // Without normalization - demonstrates the problem
+        let sorted_without_norm: Vec<_> = versions
+            .iter()
+            .sorted_by_cached_key(|v| (Versioning::new(v), v.to_string()))
+            .collect();
+        println!("Without normalization: {:?}", sorted_without_norm);
+
+        // With normalization - the fix
+        let sorted_with_norm: Vec<_> = versions
+            .iter()
+            .sorted_by_cached_key(|v| {
+                let normalized = normalize_version_for_sort(v);
+                (Versioning::new(normalized), v.to_string())
+            })
+            .collect();
+        println!("With normalization: {:?}", sorted_with_norm);
+
+        // With the fix, v2.0.51 should sort between 2.0.35 and 2.0.52
+        // The highest version should be 2.0.52
+        assert_eq!(**sorted_with_norm.last().unwrap(), "2.0.52");
+
+        // v2.0.51 should be second to last
+        assert_eq!(**sorted_with_norm.get(1).unwrap(), "v2.0.51");
+
+        // 2.0.35 should be first
+        assert_eq!(**sorted_with_norm.first().unwrap(), "2.0.35");
+    }
+}
